==> letschatty-0.2.25.tar.gz: letschatty-0.2.25/src/letschatty/models/analytics/smart_messages/topic.py <==
from __future__ import annotations
from datetime import datetime, timedelta
from typing import Optional, List
from bson.objectid import ObjectId
from ...base_models.chatty_asset_model import ChattyAssetModel
from ...utils.types.serializer_type import SerializerType
from pydantic import Field, field_validator, model_validator

from ...utils.types import StrObjectId
from .topic_message import MessageTopic

class Topic(ChattyAssetModel):
    name: str
    default_source_id: StrObjectId = Field(default_factory=lambda: str(ObjectId()))
    messages: List[MessageTopic] = Field(default_factory=list)
    lock_duration: timedelta = Field(default=timedelta(seconds=10))
    
    exclude_fields = {
        SerializerType.FRONTEND_ASSET_PREVIEW: {"default_source_id", "messages", "lock_duration"}
    }
    
    def model_dump(self, *args, **kwargs) -> dict:
        kwargs["by_alias"] = True
        return super().model_dump(*args, **kwargs)

    @model_validator(mode='after')
    def validate_messages_and_duration(self) -> 'Topic':
        """Validate messages have a default and lock_duration is correct"""
        if self.messages and not any(m.is_default for m in self.messages):
            self.messages[0].is_default = True

        return self
        
    @field_validator('lock_duration', mode='before')
    def validate_lock_duration(cls, v: int | timedelta) -> timedelta:
        if isinstance(v, int):
            return timedelta(seconds=v)
        elif isinstance(v, timedelta):
            return v
        else:
            raise ValueError("lock_duration must be a timedelta or an int")

==> letschatty-0.2.27.tar.gz: letschatty-0.2.27/src/letschatty/models/analytics/smart_messages/topic.py <==
from __future__ import annotations
from datetime import datetime, timedelta
from typing import Optional, List
from bson.objectid import ObjectId
from ...base_models.chatty_asset_model import ChattyAssetModel
from ...utils.types.serializer_type import SerializerType
from pydantic import Field, field_validator, model_validator

from ...utils.types import StrObjectId
from .topic_message import MessageTopic

class Topic(ChattyAssetModel):
    name: str
    default_source_id: StrObjectId = Field(default_factory=lambda: str(ObjectId()))
    messages: List[MessageTopic] = Field(default_factory=list)
    lock_duration: timedelta = Field(default=timedelta(seconds=10))
    
    exclude_fields = {
        SerializerType.FRONTEND_ASSET_PREVIEW: {"default_source_id", "messages", "lock_duration"}
    }
    
    def model_dump(self, *args, **kwargs) -> dict:
        kwargs["by_alias"] = True
        dump = super().model_dump(*args, **kwargs)
        dump["lock_duration"] = int(self.lock_duration.total_seconds())
        return dump

    @model_validator(mode='after')
    def validate_messages_and_duration(self) -> 'Topic':
        """Validate messages have a default and lock_duration is correct"""
        if self.messages and not any(m.is_default for m in self.messages):
            self.messages[0].is_default = True

        return self
        
    @field_validator('lock_duration', mode='before')
    def validate_lock_duration(cls, v: int | timedelta) -> timedelta:
        if isinstance(v, int):
            return timedelta(seconds=v)
        elif isinstance(v, timedelta):
            return v
        else:
            raise ValueError("lock_duration must be a timedelta or an int")
